==> ocaml_4.05.0.orig.tar.xz: ocaml-4.05.0/otherlibs/unix/mkdir.c <==
/**************************************************************************/
/*                                                                        */
/*                                 OCaml                                  */
/*                                                                        */
/*             Xavier Leroy, projet Cristal, INRIA Rocquencourt           */
/*                                                                        */
/*   Copyright 1996 Institut National de Recherche en Informatique et     */
/*     en Automatique.                                                    */
/*                                                                        */
/*   All rights reserved.  This file is distributed under the terms of    */
/*   the GNU Lesser General Public License version 2.1, with the          */
/*   special exception on linking described in the file LICENSE.          */
/*                                                                        */
/**************************************************************************/

#include <sys/types.h>
#include <sys/stat.h>
#include <caml/mlvalues.h>
#include <caml/memory.h>
#include <caml/signals.h>
#include "unixsupport.h"

CAMLprim value unix_mkdir(value path, value perm)
{
  CAMLparam2(path, perm);
  char * p;
  int ret;
  caml_unix_check_path(path, "mkdir");
  p = caml_strdup(String_val(path));
  caml_enter_blocking_section();
  ret = mkdir(p, Int_val(perm));
  caml_leave_blocking_section();
  caml_stat_free(p);
  if (ret == -1) uerror("mkdir", path);
  CAMLreturn(Val_unit);
}

==> ocaml_4.08.1.orig.tar.xz: ocaml-4.08.1/otherlibs/unix/mkdir.c <==
/**************************************************************************/
/*                                                                        */
/*                                 OCaml                                  */
/*                                                                        */
/*             Xavier Leroy, projet Cristal, INRIA Rocquencourt           */
/*                                                                        */
/*   Copyright 1996 Institut National de Recherche en Informatique et     */
/*     en Automatique.                                                    */
/*                                                                        */
/*   All rights reserved.  This file is distributed under the terms of    */
/*   the GNU Lesser General Public License version 2.1, with the          */
/*   special exception on linking described in the file LICENSE.          */
/*                                                                        */
/**************************************************************************/

#include <sys/types.h>
#include <sys/stat.h>
#include <caml/mlvalues.h>
#include <caml/memory.h>
#include <caml/signals.h>
#include "unixsupport.h"

CAMLprim value unix_mkdir(value path, value perm)
{
  CAMLparam2(path, perm);
  char * p;
  int ret;
  caml_unix_check_path(path, "mkdir");
  p = caml_stat_strdup(String_val(path));
  caml_enter_blocking_section();
  ret = mkdir(p, Int_val(perm));
  caml_leave_blocking_section();
  caml_stat_free(p);
  if (ret == -1) uerror("mkdir", path);
  CAMLreturn(Val_unit);
}
